==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterDeploymentBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterDeploymentBuilder extends ClusterDeploymentFluentImpl<ClusterDeploymentBuilder> implements VisitableBuilder<ClusterDeployment,ClusterDeploymentBuilder>{
  public ClusterDeploymentBuilder() {
    this(false);
  }
  public ClusterDeploymentBuilder(Boolean validationEnabled) {
    this(new ClusterDeployment(), validationEnabled);
  }
  public ClusterDeploymentBuilder(ClusterDeploymentFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterDeploymentBuilder(ClusterDeploymentFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterDeployment(), validationEnabled);
  }
  public ClusterDeploymentBuilder(ClusterDeploymentFluent<?> fluent,ClusterDeployment instance) {
    this(fluent, instance, false);
  }
  public ClusterDeploymentBuilder(ClusterDeploymentFluent<?> fluent,ClusterDeployment instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterDeploymentBuilder(ClusterDeployment instance) {
    this(instance,false);
  }
  public ClusterDeploymentBuilder(ClusterDeployment instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterDeploymentFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterDeployment build() {
    ClusterDeployment buildable = new ClusterDeployment(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterDeploymentBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterDeploymentBuilder extends ClusterDeploymentFluent<ClusterDeploymentBuilder> implements VisitableBuilder<ClusterDeployment,ClusterDeploymentBuilder>{
  public ClusterDeploymentBuilder() {
    this(false);
  }
  public ClusterDeploymentBuilder(Boolean validationEnabled) {
    this(new ClusterDeployment(), validationEnabled);
  }
  public ClusterDeploymentBuilder(ClusterDeploymentFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterDeploymentBuilder(ClusterDeploymentFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterDeployment(), validationEnabled);
  }
  public ClusterDeploymentBuilder(ClusterDeploymentFluent<?> fluent,ClusterDeployment instance) {
    this(fluent, instance, false);
  }
  public ClusterDeploymentBuilder(ClusterDeploymentFluent<?> fluent,ClusterDeployment instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterDeployment());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterDeploymentBuilder(ClusterDeployment instance) {
    this(instance,false);
  }
  public ClusterDeploymentBuilder(ClusterDeployment instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterDeployment());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterDeploymentFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterDeployment build() {
    ClusterDeployment buildable = new ClusterDeployment(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildSpec(),fluent.buildStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
